@@ -1,12 +1,12 @@
 package WWW::LinkChecker::Internal;
-$WWW::LinkChecker::Internal::VERSION = '0.6.0';
+$WWW::LinkChecker::Internal::VERSION = '0.8.0';
 use 5.014;
 use strict;
 use warnings;
 
 
 
-1; # End of WWW::LinkChecker::Internal
+1;    # End of WWW::LinkChecker::Internal
 
 __END__
 
@@ -20,7 +20,7 @@ WWW::LinkChecker::Internal - Check a web site for broken internal links.
 
 =head1 VERSION
 
-version 0.6.0
+version 0.8.0
 
 =head1 SYNOPSIS
 
@@ -94,37 +94,10 @@ WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2019 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/perl-www-linkchecker-internal/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc WWW::LinkChecker::Internal
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -142,14 +115,6 @@ L<https://metacpan.org/release/WWW-LinkChecker-Internal>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/WWW-LinkChecker-Internal>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -158,22 +123,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=WWW-LinkChecker-Internal>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/WWW-LinkChecker-Internal>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/WWW-LinkChecker-Internal>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -222,4 +171,25 @@ L<https://github.com/shlomif/perl-www-linkchecker-internal>
 
   git clone git://github.com/shlomif/perl-www-linkchecker-internal.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-www-linkchecker-internal/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2020 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
 =cut
